@@ -4,6 +4,7 @@ import random
 from itertools import permutations
 from lk_heuristic.models.edge import Edge
 from lk_heuristic.models.tour import Tour
+from lk_heuristic.models.node import NodePivot
 
 
 class Tsp:
@@ -15,7 +16,7 @@ class Tsp:
     # this is required when computing the gain in "simmetric" tours, to avoid incorrect calculations when using just "> 0"
     gain_precision = 0.01
 
-    def __init__(self, nodes, cost_function, shuffle=False, backtracking=(5, 5), reduction_level=4, reduction_cycle=4, logging_level=logging.INFO):
+    def __init__(self, nodes, cost_function, shuffle=False, backtracking=(5, 5), reduction_level=4, reduction_cycle=4, tour_type="cycle", logging_level=logging.INFO):
         """
         The TSP input is a list of nodes which will be used as input to build a tour and a cost function to build the cost matrix.
 
@@ -31,6 +32,8 @@ class Tsp:
         :type reduction_level: int
         :param reduction_cycle: the number of optimization cycles when reducted edges will start being considered
         :type reduction_cycle: int
+        :param tour_type: the type of the tour (either 'path' or 'cycle')
+        :type tour_type: str
         :param logging_level: the level for logging messages
         :type logging_level: int
         """
@@ -42,8 +45,11 @@ class Tsp:
         # initialize nodes
         self.nodes = nodes
 
-        # initialize the tour using the nodes
-        self.tour = Tour(self.nodes)
+        # initialize the tour type
+        self.tour_type = tour_type
+
+        # initialize the tour using the nodes and the tour type
+        self.tour = Tour(self.nodes, t=tour_type)
 
         # shuffle the tour nodes
         if shuffle:
@@ -115,7 +121,10 @@ class Tsp:
                 n2 = self.nodes[j]
 
                 # compute the cost between nodes
-                cost = cost_func(n1, n2)
+                # for hamiltonian path, pivot nodes are used and edges containing those nodes will have zero cost
+                cost = 0
+                if not (type(n1) == NodePivot or type(n2) == NodePivot):
+                    cost = cost_func(n1, n2)
 
                 # update cost matrix
                 self.cost_matrix[(n1.id, n2.id)] = cost
@@ -632,10 +641,6 @@ class Tsp:
                                 # compute the new cost for the new tour
                                 self.tour.set_cost(self.cost_matrix)
 
-                                # add the solution string to the set (direct and reversed order)
-                                self.solutions.add(hash(tuple([node.succ.id for node in self.tour.nodes])))
-                                self.solutions.add(hash(tuple([node.pred.id for node in self.tour.nodes])))
-
                                 # reset close gains
                                 self.close_gains.clear()
 
@@ -696,6 +701,10 @@ class Tsp:
         # update improvement cycle count
         self.cycles += 1
 
+        # add the current solution string to the set (direct and reversed order)
+        self.solutions.add(hash(tuple([node.succ.id for node in self.tour.nodes])))
+        self.solutions.add(hash(tuple([node.pred.id for node in self.tour.nodes])))
+
         # initialize or update the reduction edges by intersecting reduction edges with new tour edges
         self.reduction_edges = set(self.tour.edges) if self.cycles == 1 else self.reduction_edges.intersection(self.tour.edges)
 
@@ -774,10 +783,6 @@ class Tsp:
                 # compute the current gain value
                 curr_gain = gain + (broken_cost - joined_cost)
 
-                # check for repeated tours (one of LK refinements is to remove repeated tours that already were tested and checked that can't be improved). O(n) complexity like the one done below could be improved with hashingtables, as done by Helsgaum.
-                if (hash(tuple([node.succ.id for node in self.tour.nodes])) in self.solutions):
-                    return False
-
                 # if gain is positive, restart the search with new tour
                 # this is a simplification of LK from Helsgaun paper. LK suggest to continue the search, while Helsgaun suggest to simplify the algorithm
                 if curr_gain > self.gain_precision:
@@ -899,9 +904,6 @@ class Tsp:
                             # reset the swap stack
                             self.tour.swap_stack.clear()
 
-                            # add the solution string to the set
-                            self.solutions.add(hash(tuple([node.succ.id for node in self.tour.nodes])))
-
                             # return true value
                             return True
                         else:
